@@ -42,12 +42,12 @@ print()
 
 
 print('Now reading FORCE_CONSTANTS...')
-K = read.read_FC(file_FC)
+K = np.loadtxt(file_FC)
 print('Now calculating velocities...')
 
 # =============================================================================
 # Supercell and BZ cration
-Nqs_path, ks_path, ks_scaled_path, kk, x_labels, Hk = util.get_commensurate_kpath(file_initial_conf, N1,N2,N3, N1,N2,N3, kinput_scaled, np.array([' ' for i in range(len(kinput_scaled))]))
+Nqs_path, ks_path, ks_path_scaled, kk, x_labels, Hk = util.get_commensurate_kpath(file_initial_conf, N1,N2,N3, N1,N2,N3, kinput_scaled, np.array([' ' for i in range(len(kinput_scaled))]))
 SCell, Ruc, Suc, R0, R0_repeat, S0, masses, masses_uc = read.read_SPOSCAR_and_masses(file_initial_conf, n_atom_unit_cell, Masses, N1, N2, N3)
 # =============================================================================
 
@@ -83,15 +83,15 @@ C = Ctot[0:int(len(Ctot)/2)].real
 # =============================================================================
 
 
-quasiparticles_kpoints, quasiparticles_info = np.zeros((Nqs_path, 3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3))
+quasiparticles_kpoints, quasiparticles_info, raw_data_info = np.zeros((Nqs_path, 3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3))
 print('\nDone. Performing calculation of renormalised FORCE CONSTANTS...\n')
-kpoints_scal, kpoints = util.get_kgrid(N1,N2,N3, Hk)
+kpoints_scaled, kpoints = util.get_kgrid(N1,N2,N3, Hk)
 # you're not using irreducible kpoints anymore, couse it doesn't work for BaTiO3, unless you do adjustments
-# irr_kpoints, irr_kpoints_scal, weights, permutations_types = util.get_irr_ks(kpoints, kpoints_scal)
+# irr_kpoints, irr_kpoints_scaled, weights, permutations_types = util.get_irr_ks(kpoints, kpoints_scaled)
 Ds = np.zeros((len(kpoints),tot_atoms_uc*3, tot_atoms_uc*3), dtype=complex)
 for i in range(len(kpoints)):
     k = kpoints[i]
-    k_scal = kpoints_scal[i]
+    k_scal = kpoints_scaled[i]
     # thisk_permutations = permutations_types[i]
     # weight = weights[i]
     print('\t kpoint scaled: ', i, k_scal)
@@ -122,27 +122,33 @@ for i in range(len(kpoints)):
     print('\t DOS for projected k-ni: ', area_q_proj)
     # area_q_proj[area_q_proj < 1e-05] = 100 # this is in case of acoustic Gamma
     # Sq_proj = Sq_proj/area_q_proj # this is to have the unoccupied DOS
-    
-    # print(np.trapz(S,freq))
-    # import matplotlib.pyplot as plt
-    # fig,ax = plt.subplots()
-    # ax.plot(freq, Sq_proj)
+
 
     Params = np.zeros((3,tot_atoms_uc*3))
+    raw_data_Params = np.zeros((2,tot_atoms_uc*3))
     for n in range(tot_atoms_uc*3):
         x_data, y_data = freq[0:int(tau/2)], Sq_proj[0:int(tau/2),n]
+        
         popt, perr = util.fit_to_lorentzian(x_data, y_data, k, n)
         Params[:,n] = popt
         #now you go apply to Voigt equation for the sigmas
-        sig = popt[-1]*0.42
-        fmax, fl = util.voigt_eq(n, k_scal, x_data, y_data, sig)
+        fmax, fl = util.voigt_eq(n, k_scal, x_data, y_data, sig=popt[-1]*0.42)
         Params[-1,n] = fl
-        if(np.any(np.all(np.isclose(k_scal , ks_scaled_path), axis=1))):
+        
+        x_avg, std = util.get_avg_std(x_data, y_data, k, n)
+        raw_data_Params[0,n], raw_data_Params[-1,n] = x_avg, std
+        
+        if(np.any(np.all(np.isclose(k_scal , ks_path_scaled), axis=1))):
             print()
             print('\t\tFitting to Lorentzian, mode '+str(n)+'...')
             print('\t\tResonant frequency omega =',np.round(popt[0],2),' +-',np.round(perr[0],3))
             print('\t\tLinewidth gamma =',np.round(popt[2],2),' +-',np.round(perr[2],3))
             print()
+            print('\t\tTreating it as a prob density, mode '+str(n)+'...')
+            print('\t\tResonant frequency omega =',np.round(x_avg,2))
+            print('\t\tLinewidth gamma =',np.round(std,2))
+            print()
+            print()
 # =============================================================================
 
 # =============================================================================
@@ -156,14 +162,15 @@ for i in range(len(kpoints)):
 
 # =============================================================================
 #  writing to file if in path
-    check_is_symm_kpoint = util.check_is_symm(k_scal, ks_scaled_path)
+    check_is_symm_kpoint = util.check_is_symm(k_scal, ks_path_scaled)
     if(len(check_is_symm_kpoint) > 0):
         # print(check_is_symm_kpoint)
         for l in range(len(check_is_symm_kpoint)):
             kpoint = check_is_symm_kpoint[l]
-            index_q = np.argwhere(np.all(np.isclose(kpoint , ks_scaled_path), axis=1)).flatten()
+            index_q = np.argwhere(np.all(np.isclose(kpoint , ks_path_scaled), axis=1)).flatten()
             quasiparticles_kpoints[index_q,:] = kpoint
             quasiparticles_info[index_q,:,:] = Params
+            raw_data_info[index_q,:,:] = raw_data_Params
             ZS[:,index_q+2] = Sq[0:meta].reshape(meta,1)
             Zqs[index_q,:,0] = Sq[0:meta]
             Zqs[index_q,:,1:] = Sq_proj[0:meta,:]
@@ -173,11 +180,10 @@ for i in range(len(kpoints)):
     
 util.save_quasiparticles('Zqs', quasiparticles_kpoints, Zqs)
 util.save_quasiparticles('quasiparticles', quasiparticles_kpoints, quasiparticles_info)  
+util.save_quasiparticles('non_quasiparticles', quasiparticles_kpoints, raw_data_info)  
 util.save('C_t', np.vstack((tall[0:len(C)],C)).T)
 util.save('ZS', ZS)
 
-
-
 # SCell_fc, R0_fc, R_fc = util.get_R_FC(N1, N2, N3, 4,4,4,tot_atoms_uc, Suc, SCell) 
 K_renorm = util.get_K_renorm_old(tot_atoms_uc,N1,N2,N3, SCell, R0, kpoints, Ds)
 # K_renorm = util.get_K_renorm(tot_atoms_uc,N1,N2,N3, SCell, R0, irr_kpoints, permutations_types, Ds)
