@@ -189,7 +189,7 @@ def get_kpath_many(kinput, Hk, npoints=20):
     return ks_scal, ks, distances
 
 def get_kgrid(N1k, N2k, N3k, Hk):
-    x,y,z = np.linspace(0,1,N1k+1)[0:-1], np.linspace(0,1,N2k+1)[0:-1], np.linspace(0,1,N3k+1)[0:-1]
+    x,y,z = np.linspace(0,1,N1k+1)[0:-1]-0.5, np.linspace(0,1,N2k+1)[0:-1]-0.5, np.linspace(0,1,N3k+1)[0:-1]-0.5
     kpoints_scal = np.array(np.meshgrid(x,y,z)).T.reshape(-1,3)
     kpoints = np.dot(Hk,kpoints_scal.T).T
     return kpoints_scal, kpoints
@@ -1131,7 +1131,18 @@ def voigt_eq(n, k, freq, Z, sig):
 #   www = (-fv**2+fg**2)/(-fv)
     return freq[f_max], fl
 
-
+def get_avg_std(x_data, y_data, k, n):
+    if(n in [0,1,2] and np.allclose(k, [0,0,0])): #if acoustic modes at Gamma, don't do anything
+        x_avg, std = 0, 0
+        return x_avg, std
+    
+    Integral = np.trapz(y_data, x_data)
+    p_dist = y_data  / Integral
+    
+    x_avg = np.trapz(x_data*p_dist, x_data)
+    var = np.trapz( (x_data-x_avg)**2 * p_dist, x_data )
+    std = np.sqrt(var) 
+    return x_avg, std
 
 
 
